# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/core_services.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import core_adapter_pb2 as voltha__protos_dot_core__adapter__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import device_pb2 as voltha__protos_dot_device__pb2
from voltha_protos import health_pb2 as voltha__protos_dot_health__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/core_services.proto',
  package='core_service',
  syntax='proto3',
  serialized_options=b'\n org.opencord.voltha.core_serviceB\021VolthaCoreServiceZ4github.com/opencord/voltha-protos/v5/go/core_service',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!voltha_protos/core_services.proto\x12\x0c\x63ore_service\x1a\x1bgoogle/protobuf/empty.proto\x1a voltha_protos/core_adapter.proto\x1a\x1avoltha_protos/common.proto\x1a\x1avoltha_protos/device.proto\x1a\x1avoltha_protos/health.proto2\xf9\x0b\n\x0b\x43oreService\x12;\n\x0fGetHealthStatus\x12\x12.common.Connection\x1a\x14.health.HealthStatus\x12L\n\x0fRegisterAdapter\x12!.core_adapter.AdapterRegistration\x1a\x16.google.protobuf.Empty\x12\x36\n\x0c\x44\x65viceUpdate\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x33\n\x0bPortCreated\x12\x0c.device.Port\x1a\x16.google.protobuf.Empty\x12I\n\x10PortsStateUpdate\x12\x1d.core_adapter.PortStateFilter\x1a\x16.google.protobuf.Empty\x12\x34\n\x0e\x44\x65leteAllPorts\x12\n.common.ID\x1a\x16.google.protobuf.Empty\x12\x37\n\rGetDevicePort\x12\x18.core_adapter.PortFilter\x1a\x0c.device.Port\x12,\n\x0fListDevicePorts\x12\n.common.ID\x1a\r.device.Ports\x12L\n\x11\x44\x65viceStateUpdate\x12\x1f.core_adapter.DeviceStateFilter\x1a\x16.google.protobuf.Empty\x12\x41\n\x14\x44\x65vicePMConfigUpdate\x12\x11.device.PmConfigs\x1a\x16.google.protobuf.Empty\x12\x44\n\x13\x43hildDeviceDetected\x12\x1d.core_adapter.DeviceDiscovery\x1a\x0e.device.Device\x12\x36\n\x10\x43hildDevicesLost\x12\n.common.ID\x1a\x16.google.protobuf.Empty\x12:\n\x14\x43hildDevicesDetected\x12\n.common.ID\x1a\x16.google.protobuf.Empty\x12\'\n\tGetDevice\x12\n.common.ID\x1a\x0e.device.Device\x12\x41\n\x0eGetChildDevice\x12\x1f.core_adapter.ChildDeviceFilter\x1a\x0e.device.Device\x12.\n\x0fGetChildDevices\x12\n.common.ID\x1a\x0f.device.Devices\x12>\n\x0cSendPacketIn\x12\x16.core_adapter.PacketIn\x1a\x16.google.protobuf.Empty\x12H\n\x12\x44\x65viceReasonUpdate\x12\x1a.core_adapter.DeviceReason\x1a\x16.google.protobuf.Empty\x12\x42\n\x0fPortStateUpdate\x12\x17.core_adapter.PortState\x1a\x16.google.protobuf.Empty\x12;\n\x15ReconcileChildDevices\x12\n.common.ID\x1a\x16.google.protobuf.Empty\x12M\n\x1eGetChildDeviceWithProxyAddress\x12\x1b.device.Device.ProxyAddress\x1a\x0e.device.Device\x12\x33\n\x08GetPorts\x12\x18.core_adapter.PortFilter\x1a\r.device.Ports\x12N\n\x13\x43hildrenStateUpdate\x12\x1f.core_adapter.DeviceStateFilter\x1a\x16.google.protobuf.Empty\x12\x44\n\x13UpdateImageDownload\x12\x15.device.ImageDownload\x1a\x16.google.protobuf.EmptyBk\n org.opencord.voltha.core_serviceB\x11VolthaCoreServiceZ4github.com/opencord/voltha-protos/v5/go/core_serviceb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,voltha__protos_dot_core__adapter__pb2.DESCRIPTOR,voltha__protos_dot_common__pb2.DESCRIPTOR,voltha__protos_dot_device__pb2.DESCRIPTOR,voltha__protos_dot_health__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_CORESERVICE = _descriptor.ServiceDescriptor(
  name='CoreService',
  full_name='core_service.CoreService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=199,
  serialized_end=1728,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetHealthStatus',
    full_name='core_service.CoreService.GetHealthStatus',
    index=0,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._CONNECTION,
    output_type=voltha__protos_dot_health__pb2._HEALTHSTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterAdapter',
    full_name='core_service.CoreService.RegisterAdapter',
    index=1,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._ADAPTERREGISTRATION,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeviceUpdate',
    full_name='core_service.CoreService.DeviceUpdate',
    index=2,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PortCreated',
    full_name='core_service.CoreService.PortCreated',
    index=3,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._PORT,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PortsStateUpdate',
    full_name='core_service.CoreService.PortsStateUpdate',
    index=4,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._PORTSTATEFILTER,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAllPorts',
    full_name='core_service.CoreService.DeleteAllPorts',
    index=5,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDevicePort',
    full_name='core_service.CoreService.GetDevicePort',
    index=6,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._PORTFILTER,
    output_type=voltha__protos_dot_device__pb2._PORT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDevicePorts',
    full_name='core_service.CoreService.ListDevicePorts',
    index=7,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_device__pb2._PORTS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeviceStateUpdate',
    full_name='core_service.CoreService.DeviceStateUpdate',
    index=8,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._DEVICESTATEFILTER,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DevicePMConfigUpdate',
    full_name='core_service.CoreService.DevicePMConfigUpdate',
    index=9,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._PMCONFIGS,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChildDeviceDetected',
    full_name='core_service.CoreService.ChildDeviceDetected',
    index=10,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._DEVICEDISCOVERY,
    output_type=voltha__protos_dot_device__pb2._DEVICE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChildDevicesLost',
    full_name='core_service.CoreService.ChildDevicesLost',
    index=11,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChildDevicesDetected',
    full_name='core_service.CoreService.ChildDevicesDetected',
    index=12,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDevice',
    full_name='core_service.CoreService.GetDevice',
    index=13,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_device__pb2._DEVICE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetChildDevice',
    full_name='core_service.CoreService.GetChildDevice',
    index=14,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._CHILDDEVICEFILTER,
    output_type=voltha__protos_dot_device__pb2._DEVICE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetChildDevices',
    full_name='core_service.CoreService.GetChildDevices',
    index=15,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_device__pb2._DEVICES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendPacketIn',
    full_name='core_service.CoreService.SendPacketIn',
    index=16,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._PACKETIN,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeviceReasonUpdate',
    full_name='core_service.CoreService.DeviceReasonUpdate',
    index=17,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._DEVICEREASON,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PortStateUpdate',
    full_name='core_service.CoreService.PortStateUpdate',
    index=18,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._PORTSTATE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReconcileChildDevices',
    full_name='core_service.CoreService.ReconcileChildDevices',
    index=19,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetChildDeviceWithProxyAddress',
    full_name='core_service.CoreService.GetChildDeviceWithProxyAddress',
    index=20,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE_PROXYADDRESS,
    output_type=voltha__protos_dot_device__pb2._DEVICE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPorts',
    full_name='core_service.CoreService.GetPorts',
    index=21,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._PORTFILTER,
    output_type=voltha__protos_dot_device__pb2._PORTS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChildrenStateUpdate',
    full_name='core_service.CoreService.ChildrenStateUpdate',
    index=22,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._DEVICESTATEFILTER,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateImageDownload',
    full_name='core_service.CoreService.UpdateImageDownload',
    index=23,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CORESERVICE)

DESCRIPTOR.services_by_name['CoreService'] = _CORESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/core.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/core.proto',
  package='core',
  syntax='proto3',
  serialized_options=b'\n\030org.opencord.voltha.coreZ,github.com/opencord/voltha-protos/v5/go/core',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18voltha_protos/core.proto\x12\x04\x63ore\"\xef\x01\n\x14\x44\x65viceTransientState\x12\x39\n\x0ftransient_state\x18\x01 \x01(\x0e\x32 .core.DeviceTransientState.Types\"\x9b\x01\n\x05Types\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03\x41NY\x10\x01\x12\x12\n\x0e\x46ORCE_DELETING\x10\x02\x12\x19\n\x15\x44\x45LETING_FROM_ADAPTER\x10\x03\x12\"\n\x1e\x44\x45LETING_POST_ADAPTER_RESPONSE\x10\x04\x12\x11\n\rDELETE_FAILED\x10\x05\x12\x19\n\x15RECONCILE_IN_PROGRESS\x10\x06\x42H\n\x18org.opencord.voltha.coreZ,github.com/opencord/voltha-protos/v5/go/coreb\x06proto3'
)



_DEVICETRANSIENTSTATE_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='core.DeviceTransientState.Types',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ANY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORCE_DELETING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING_FROM_ADAPTER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING_POST_ADAPTER_RESPONSE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETE_FAILED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RECONCILE_IN_PROGRESS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=119,
  serialized_end=274,
)
_sym_db.RegisterEnumDescriptor(_DEVICETRANSIENTSTATE_TYPES)


_DEVICETRANSIENTSTATE = _descriptor.Descriptor(
  name='DeviceTransientState',
  full_name='core.DeviceTransientState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transient_state', full_name='core.DeviceTransientState.transient_state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DEVICETRANSIENTSTATE_TYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35,
  serialized_end=274,
)

_DEVICETRANSIENTSTATE.fields_by_name['transient_state'].enum_type = _DEVICETRANSIENTSTATE_TYPES
_DEVICETRANSIENTSTATE_TYPES.containing_type = _DEVICETRANSIENTSTATE
DESCRIPTOR.message_types_by_name['DeviceTransientState'] = _DEVICETRANSIENTSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DeviceTransientState = _reflection.GeneratedProtocolMessageType('DeviceTransientState', (_message.Message,), {
  'DESCRIPTOR' : _DEVICETRANSIENTSTATE,
  '__module__' : 'voltha_protos.core_pb2'
  # @@protoc_insertion_point(class_scope:core.DeviceTransientState)
  })
_sym_db.RegisterMessage(DeviceTransientState)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/adapter_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import core_adapter_pb2 as voltha__protos_dot_core__adapter__pb2
from voltha_protos import device_pb2 as voltha__protos_dot_device__pb2
from voltha_protos import extensions_pb2 as voltha__protos_dot_extensions__pb2
from voltha_protos import health_pb2 as voltha__protos_dot_health__pb2
from voltha_protos import voltha_pb2 as voltha__protos_dot_voltha__pb2
try:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_common__pb2
except AttributeError:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.common_pb2
from voltha_protos import omci_test_pb2 as voltha__protos_dot_omci__test__pb2
from voltha_protos import events_pb2 as voltha__protos_dot_events__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/adapter_service.proto',
  package='adapter_service',
  syntax='proto3',
  serialized_options=b'\n#org.opencord.voltha.adapter_serviceB\024VolthaAdapterServiceZ7github.com/opencord/voltha-protos/v5/go/adapter_service',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#voltha_protos/adapter_service.proto\x12\x0f\x61\x64\x61pter_service\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1avoltha_protos/common.proto\x1a voltha_protos/core_adapter.proto\x1a\x1avoltha_protos/device.proto\x1a\x1evoltha_protos/extensions.proto\x1a\x1avoltha_protos/health.proto\x1a\x1avoltha_protos/voltha.proto\x1a\x1dvoltha_protos/omci_test.proto\x1a\x1avoltha_protos/events.proto2\x94\x13\n\x0e\x41\x64\x61pterService\x12;\n\x0fGetHealthStatus\x12\x12.common.Connection\x1a\x14.health.HealthStatus\x12\x35\n\x0b\x41\x64optDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x39\n\x0fReconcileDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x36\n\x0c\x44\x65leteDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x37\n\rDisableDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x38\n\x0eReEnableDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x36\n\x0cRebootDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x38\n\x0eSelfTestDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x42\n\x10GetOfpDeviceInfo\x12\x0e.device.Device\x1a\x1e.core_adapter.SwitchCapability\x12\x39\n\x0f\x43hildDeviceLost\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x32\n\nEnablePort\x12\x0c.device.Port\x1a\x16.google.protobuf.Empty\x12\x33\n\x0b\x44isablePort\x12\x0c.device.Port\x1a\x16.google.protobuf.Empty\x12\x42\n\x0fUpdateFlowsBulk\x12\x17.core_adapter.BulkFlows\x1a\x16.google.protobuf.Empty\x12R\n\x18UpdateFlowsIncrementally\x12\x1e.core_adapter.IncrementalFlows\x1a\x16.google.protobuf.Empty\x12@\n\rSendPacketOut\x12\x17.core_adapter.PacketOut\x1a\x16.google.protobuf.Empty\x12\x45\n\x0eUpdatePmConfig\x12\x1b.core_adapter.PmConfigsInfo\x1a\x16.google.protobuf.Empty\x12S\n\x10\x44ownloadOnuImage\x12\".device.DeviceImageDownloadRequest\x1a\x1b.device.DeviceImageResponse\x12L\n\x11GetOnuImageStatus\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\x12O\n\x14\x41\x62ortOnuImageUpgrade\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\x12-\n\x0cGetOnuImages\x12\n.common.ID\x1a\x11.device.OnuImages\x12K\n\x10\x41\x63tivateOnuImage\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\x12I\n\x0e\x43ommitOnuImage\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\x12O\n\rDownloadImage\x12\".core_adapter.ImageDownloadMessage\x1a\x15.device.ImageDownload\"\x03\x88\x02\x01\x12X\n\x16GetImageDownloadStatus\x12\".core_adapter.ImageDownloadMessage\x1a\x15.device.ImageDownload\"\x03\x88\x02\x01\x12U\n\x13\x43\x61ncelImageDownload\x12\".core_adapter.ImageDownloadMessage\x1a\x15.device.ImageDownload\"\x03\x88\x02\x01\x12U\n\x13\x41\x63tivateImageUpdate\x12\".core_adapter.ImageDownloadMessage\x1a\x15.device.ImageDownload\"\x03\x88\x02\x01\x12S\n\x11RevertImageUpdate\x12\".core_adapter.ImageDownloadMessage\x1a\x15.device.ImageDownload\"\x03\x88\x02\x01\x12;\n\rStartOmciTest\x12\x16.core_adapter.OMCITest\x1a\x12.omci.TestResponse\x12J\n\rSimulateAlarm\x12\".core_adapter.SimulateAlarmMessage\x1a\x15.common.OperationResp\x12;\n\rSuppressEvent\x12\x12.event.EventFilter\x1a\x16.google.protobuf.Empty\x12=\n\x0fUnSuppressEvent\x12\x12.event.EventFilter\x1a\x16.google.protobuf.Empty\x12H\n\x0bGetExtValue\x12 .core_adapter.GetExtValueMessage\x1a\x17.extension.ReturnValues\x12G\n\x0bSetExtValue\x12 .core_adapter.SetExtValueMessage\x1a\x16.google.protobuf.Empty\x12U\n\x0eGetSingleValue\x12 .extension.SingleGetValueRequest\x1a!.extension.SingleGetValueResponse\x12U\n\x0eSetSingleValue\x12 .extension.SingleSetValueRequest\x1a!.extension.SingleSetValueResponseBt\n#org.opencord.voltha.adapter_serviceB\x14VolthaAdapterServiceZ7github.com/opencord/voltha-protos/v5/go/adapter_serviceb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,voltha__protos_dot_common__pb2.DESCRIPTOR,voltha__protos_dot_core__adapter__pb2.DESCRIPTOR,voltha__protos_dot_device__pb2.DESCRIPTOR,voltha__protos_dot_extensions__pb2.DESCRIPTOR,voltha__protos_dot_health__pb2.DESCRIPTOR,voltha__protos_dot_voltha__pb2.DESCRIPTOR,voltha__protos_dot_omci__test__pb2.DESCRIPTOR,voltha__protos_dot_events__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_ADAPTERSERVICE = _descriptor.ServiceDescriptor(
  name='AdapterService',
  full_name='adapter_service.AdapterService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=323,
  serialized_end=2775,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetHealthStatus',
    full_name='adapter_service.AdapterService.GetHealthStatus',
    index=0,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._CONNECTION,
    output_type=voltha__protos_dot_health__pb2._HEALTHSTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AdoptDevice',
    full_name='adapter_service.AdapterService.AdoptDevice',
    index=1,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReconcileDevice',
    full_name='adapter_service.AdapterService.ReconcileDevice',
    index=2,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDevice',
    full_name='adapter_service.AdapterService.DeleteDevice',
    index=3,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DisableDevice',
    full_name='adapter_service.AdapterService.DisableDevice',
    index=4,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReEnableDevice',
    full_name='adapter_service.AdapterService.ReEnableDevice',
    index=5,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RebootDevice',
    full_name='adapter_service.AdapterService.RebootDevice',
    index=6,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SelfTestDevice',
    full_name='adapter_service.AdapterService.SelfTestDevice',
    index=7,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetOfpDeviceInfo',
    full_name='adapter_service.AdapterService.GetOfpDeviceInfo',
    index=8,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=voltha__protos_dot_core__adapter__pb2._SWITCHCAPABILITY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChildDeviceLost',
    full_name='adapter_service.AdapterService.ChildDeviceLost',
    index=9,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EnablePort',
    full_name='adapter_service.AdapterService.EnablePort',
    index=10,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._PORT,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DisablePort',
    full_name='adapter_service.AdapterService.DisablePort',
    index=11,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._PORT,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFlowsBulk',
    full_name='adapter_service.AdapterService.UpdateFlowsBulk',
    index=12,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._BULKFLOWS,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFlowsIncrementally',
    full_name='adapter_service.AdapterService.UpdateFlowsIncrementally',
    index=13,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._INCREMENTALFLOWS,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendPacketOut',
    full_name='adapter_service.AdapterService.SendPacketOut',
    index=14,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._PACKETOUT,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdatePmConfig',
    full_name='adapter_service.AdapterService.UpdatePmConfig',
    index=15,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._PMCONFIGSINFO,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DownloadOnuImage',
    full_name='adapter_service.AdapterService.DownloadOnuImage',
    index=16,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICEIMAGEDOWNLOADREQUEST,
    output_type=voltha__protos_dot_device__pb2._DEVICEIMAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetOnuImageStatus',
    full_name='adapter_service.AdapterService.GetOnuImageStatus',
    index=17,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICEIMAGEREQUEST,
    output_type=voltha__protos_dot_device__pb2._DEVICEIMAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AbortOnuImageUpgrade',
    full_name='adapter_service.AdapterService.AbortOnuImageUpgrade',
    index=18,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICEIMAGEREQUEST,
    output_type=voltha__protos_dot_device__pb2._DEVICEIMAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetOnuImages',
    full_name='adapter_service.AdapterService.GetOnuImages',
    index=19,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_device__pb2._ONUIMAGES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ActivateOnuImage',
    full_name='adapter_service.AdapterService.ActivateOnuImage',
    index=20,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICEIMAGEREQUEST,
    output_type=voltha__protos_dot_device__pb2._DEVICEIMAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CommitOnuImage',
    full_name='adapter_service.AdapterService.CommitOnuImage',
    index=21,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICEIMAGEREQUEST,
    output_type=voltha__protos_dot_device__pb2._DEVICEIMAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DownloadImage',
    full_name='adapter_service.AdapterService.DownloadImage',
    index=22,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._IMAGEDOWNLOADMESSAGE,
    output_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    serialized_options=b'\210\002\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetImageDownloadStatus',
    full_name='adapter_service.AdapterService.GetImageDownloadStatus',
    index=23,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._IMAGEDOWNLOADMESSAGE,
    output_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    serialized_options=b'\210\002\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelImageDownload',
    full_name='adapter_service.AdapterService.CancelImageDownload',
    index=24,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._IMAGEDOWNLOADMESSAGE,
    output_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    serialized_options=b'\210\002\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ActivateImageUpdate',
    full_name='adapter_service.AdapterService.ActivateImageUpdate',
    index=25,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._IMAGEDOWNLOADMESSAGE,
    output_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    serialized_options=b'\210\002\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RevertImageUpdate',
    full_name='adapter_service.AdapterService.RevertImageUpdate',
    index=26,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._IMAGEDOWNLOADMESSAGE,
    output_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    serialized_options=b'\210\002\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartOmciTest',
    full_name='adapter_service.AdapterService.StartOmciTest',
    index=27,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._OMCITEST,
    output_type=voltha__protos_dot_omci__test__pb2._TESTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SimulateAlarm',
    full_name='adapter_service.AdapterService.SimulateAlarm',
    index=28,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._SIMULATEALARMMESSAGE,
    output_type=voltha__protos_dot_common__pb2._OPERATIONRESP,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SuppressEvent',
    full_name='adapter_service.AdapterService.SuppressEvent',
    index=29,
    containing_service=None,
    input_type=voltha__protos_dot_events__pb2._EVENTFILTER,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UnSuppressEvent',
    full_name='adapter_service.AdapterService.UnSuppressEvent',
    index=30,
    containing_service=None,
    input_type=voltha__protos_dot_events__pb2._EVENTFILTER,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetExtValue',
    full_name='adapter_service.AdapterService.GetExtValue',
    index=31,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._GETEXTVALUEMESSAGE,
    output_type=voltha__protos_dot_extensions__pb2._RETURNVALUES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetExtValue',
    full_name='adapter_service.AdapterService.SetExtValue',
    index=32,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._SETEXTVALUEMESSAGE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSingleValue',
    full_name='adapter_service.AdapterService.GetSingleValue',
    index=33,
    containing_service=None,
    input_type=voltha__protos_dot_extensions__pb2._SINGLEGETVALUEREQUEST,
    output_type=voltha__protos_dot_extensions__pb2._SINGLEGETVALUERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetSingleValue',
    full_name='adapter_service.AdapterService.SetSingleValue',
    index=34,
    containing_service=None,
    input_type=voltha__protos_dot_extensions__pb2._SINGLESETVALUEREQUEST,
    output_type=voltha__protos_dot_extensions__pb2._SINGLESETVALUERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ADAPTERSERVICE)

DESCRIPTOR.services_by_name['AdapterService'] = _ADAPTERSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import health_pb2 as voltha__protos_dot_health__pb2
from voltha_protos import inter_adapter_pb2 as voltha__protos_dot_inter__adapter__pb2


class OltInterAdapterServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetHealthStatus = channel.unary_unary(
                '/olt_inter_adapter_service.OltInterAdapterService/GetHealthStatus',
                request_serializer=voltha__protos_dot_common__pb2.Connection.SerializeToString,
                response_deserializer=voltha__protos_dot_health__pb2.HealthStatus.FromString,
                )
        self.ProxyOmciRequest = channel.unary_unary(
                '/olt_inter_adapter_service.OltInterAdapterService/ProxyOmciRequest',
                request_serializer=voltha__protos_dot_inter__adapter__pb2.OmciMessage.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ProxyOmciRequests = channel.unary_unary(
                '/olt_inter_adapter_service.OltInterAdapterService/ProxyOmciRequests',
                request_serializer=voltha__protos_dot_inter__adapter__pb2.OmciMessages.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetTechProfileInstance = channel.unary_unary(
                '/olt_inter_adapter_service.OltInterAdapterService/GetTechProfileInstance',
                request_serializer=voltha__protos_dot_inter__adapter__pb2.TechProfileInstanceRequestMessage.SerializeToString,
                response_deserializer=voltha__protos_dot_inter__adapter__pb2.TechProfileDownloadMessage.FromString,
                )


class OltInterAdapterServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetHealthStatus(self, request, context):
        """GetHealthStatus is used by an OltInterAdapterService client to verify connectivity
        to the gRPC server hosting the OltInterAdapterService service
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProxyOmciRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProxyOmciRequests(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTechProfileInstance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OltInterAdapterServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetHealthStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHealthStatus,
                    request_deserializer=voltha__protos_dot_common__pb2.Connection.FromString,
                    response_serializer=voltha__protos_dot_health__pb2.HealthStatus.SerializeToString,
            ),
            'ProxyOmciRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.ProxyOmciRequest,
                    request_deserializer=voltha__protos_dot_inter__adapter__pb2.OmciMessage.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ProxyOmciRequests': grpc.unary_unary_rpc_method_handler(
                    servicer.ProxyOmciRequests,
                    request_deserializer=voltha__protos_dot_inter__adapter__pb2.OmciMessages.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetTechProfileInstance': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTechProfileInstance,
                    request_deserializer=voltha__protos_dot_inter__adapter__pb2.TechProfileInstanceRequestMessage.FromString,
                    response_serializer=voltha__protos_dot_inter__adapter__pb2.TechProfileDownloadMessage.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'olt_inter_adapter_service.OltInterAdapterService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OltInterAdapterService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetHealthStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/olt_inter_adapter_service.OltInterAdapterService/GetHealthStatus',
            voltha__protos_dot_common__pb2.Connection.SerializeToString,
            voltha__protos_dot_health__pb2.HealthStatus.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ProxyOmciRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/olt_inter_adapter_service.OltInterAdapterService/ProxyOmciRequest',
            voltha__protos_dot_inter__adapter__pb2.OmciMessage.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ProxyOmciRequests(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/olt_inter_adapter_service.OltInterAdapterService/ProxyOmciRequests',
            voltha__protos_dot_inter__adapter__pb2.OmciMessages.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTechProfileInstance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/olt_inter_adapter_service.OltInterAdapterService/GetTechProfileInstance',
            voltha__protos_dot_inter__adapter__pb2.TechProfileInstanceRequestMessage.SerializeToString,
            voltha__protos_dot_inter__adapter__pb2.TechProfileDownloadMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/omci_test.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/omci_test.proto',
  package='omci',
  syntax='proto3',
  serialized_options=b'\n\030org.opencord.voltha.omciZ,github.com/opencord/voltha-protos/v5/go/omci',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dvoltha_protos/omci_test.proto\x12\x04omci\"+\n\x0fOmciTestRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t\"u\n\x0cTestResponse\x12\x35\n\x06result\x18\x01 \x01(\x0e\x32%.omci.TestResponse.TestResponseResult\".\n\x12TestResponseResult\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07\x46\x41ILURE\x10\x01\x42H\n\x18org.opencord.voltha.omciZ,github.com/opencord/voltha-protos/v5/go/omcib\x06proto3'
)



_TESTRESPONSE_TESTRESPONSERESULT = _descriptor.EnumDescriptor(
  name='TestResponseResult',
  full_name='omci.TestResponse.TestResponseResult',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILURE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=155,
  serialized_end=201,
)
_sym_db.RegisterEnumDescriptor(_TESTRESPONSE_TESTRESPONSERESULT)


_OMCITESTREQUEST = _descriptor.Descriptor(
  name='OmciTestRequest',
  full_name='omci.OmciTestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='omci.OmciTestRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='omci.OmciTestRequest.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39,
  serialized_end=82,
)


_TESTRESPONSE = _descriptor.Descriptor(
  name='TestResponse',
  full_name='omci.TestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='omci.TestResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TESTRESPONSE_TESTRESPONSERESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=201,
)

_TESTRESPONSE.fields_by_name['result'].enum_type = _TESTRESPONSE_TESTRESPONSERESULT
_TESTRESPONSE_TESTRESPONSERESULT.containing_type = _TESTRESPONSE
DESCRIPTOR.message_types_by_name['OmciTestRequest'] = _OMCITESTREQUEST
DESCRIPTOR.message_types_by_name['TestResponse'] = _TESTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OmciTestRequest = _reflection.GeneratedProtocolMessageType('OmciTestRequest', (_message.Message,), {
  'DESCRIPTOR' : _OMCITESTREQUEST,
  '__module__' : 'voltha_protos.omci_test_pb2'
  # @@protoc_insertion_point(class_scope:omci.OmciTestRequest)
  })
_sym_db.RegisterMessage(OmciTestRequest)

TestResponse = _reflection.GeneratedProtocolMessageType('TestResponse', (_message.Message,), {
  'DESCRIPTOR' : _TESTRESPONSE,
  '__module__' : 'voltha_protos.omci_test_pb2'
  # @@protoc_insertion_point(class_scope:omci.TestResponse)
  })
_sym_db.RegisterMessage(TestResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import core_adapter_pb2 as voltha__protos_dot_core__adapter__pb2
from voltha_protos import device_pb2 as voltha__protos_dot_device__pb2
from voltha_protos import health_pb2 as voltha__protos_dot_health__pb2


class CoreServiceStub(object):
    """The CoreService is a gRPC service implemented by the Voltha RW-Core for the
    sole purpose of serving requests/updates from the Voltha adapters. 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetHealthStatus = channel.unary_unary(
                '/core_service.CoreService/GetHealthStatus',
                request_serializer=voltha__protos_dot_common__pb2.Connection.SerializeToString,
                response_deserializer=voltha__protos_dot_health__pb2.HealthStatus.FromString,
                )
        self.RegisterAdapter = channel.unary_unary(
                '/core_service.CoreService/RegisterAdapter',
                request_serializer=voltha__protos_dot_core__adapter__pb2.AdapterRegistration.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeviceUpdate = channel.unary_unary(
                '/core_service.CoreService/DeviceUpdate',
                request_serializer=voltha__protos_dot_device__pb2.Device.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.PortCreated = channel.unary_unary(
                '/core_service.CoreService/PortCreated',
                request_serializer=voltha__protos_dot_device__pb2.Port.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.PortsStateUpdate = channel.unary_unary(
                '/core_service.CoreService/PortsStateUpdate',
                request_serializer=voltha__protos_dot_core__adapter__pb2.PortStateFilter.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteAllPorts = channel.unary_unary(
                '/core_service.CoreService/DeleteAllPorts',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetDevicePort = channel.unary_unary(
                '/core_service.CoreService/GetDevicePort',
                request_serializer=voltha__protos_dot_core__adapter__pb2.PortFilter.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.Port.FromString,
                )
        self.ListDevicePorts = channel.unary_unary(
                '/core_service.CoreService/ListDevicePorts',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.Ports.FromString,
                )
        self.DeviceStateUpdate = channel.unary_unary(
                '/core_service.CoreService/DeviceStateUpdate',
                request_serializer=voltha__protos_dot_core__adapter__pb2.DeviceStateFilter.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DevicePMConfigUpdate = channel.unary_unary(
                '/core_service.CoreService/DevicePMConfigUpdate',
                request_serializer=voltha__protos_dot_device__pb2.PmConfigs.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ChildDeviceDetected = channel.unary_unary(
                '/core_service.CoreService/ChildDeviceDetected',
                request_serializer=voltha__protos_dot_core__adapter__pb2.DeviceDiscovery.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.Device.FromString,
                )
        self.ChildDevicesLost = channel.unary_unary(
                '/core_service.CoreService/ChildDevicesLost',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ChildDevicesDetected = channel.unary_unary(
                '/core_service.CoreService/ChildDevicesDetected',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetDevice = channel.unary_unary(
                '/core_service.CoreService/GetDevice',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.Device.FromString,
                )
        self.GetChildDevice = channel.unary_unary(
                '/core_service.CoreService/GetChildDevice',
                request_serializer=voltha__protos_dot_core__adapter__pb2.ChildDeviceFilter.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.Device.FromString,
                )
        self.GetChildDevices = channel.unary_unary(
                '/core_service.CoreService/GetChildDevices',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.Devices.FromString,
                )
        self.SendPacketIn = channel.unary_unary(
                '/core_service.CoreService/SendPacketIn',
                request_serializer=voltha__protos_dot_core__adapter__pb2.PacketIn.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeviceReasonUpdate = channel.unary_unary(
                '/core_service.CoreService/DeviceReasonUpdate',
                request_serializer=voltha__protos_dot_core__adapter__pb2.DeviceReason.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.PortStateUpdate = channel.unary_unary(
                '/core_service.CoreService/PortStateUpdate',
                request_serializer=voltha__protos_dot_core__adapter__pb2.PortState.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ReconcileChildDevices = channel.unary_unary(
                '/core_service.CoreService/ReconcileChildDevices',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetChildDeviceWithProxyAddress = channel.unary_unary(
                '/core_service.CoreService/GetChildDeviceWithProxyAddress',
                request_serializer=voltha__protos_dot_device__pb2.Device.ProxyAddress.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.Device.FromString,
                )
        self.GetPorts = channel.unary_unary(
                '/core_service.CoreService/GetPorts',
                request_serializer=voltha__protos_dot_core__adapter__pb2.PortFilter.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.Ports.FromString,
                )
        self.ChildrenStateUpdate = channel.unary_unary(
                '/core_service.CoreService/ChildrenStateUpdate',
                request_serializer=voltha__protos_dot_core__adapter__pb2.DeviceStateFilter.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateImageDownload = channel.unary_unary(
                '/core_service.CoreService/UpdateImageDownload',
                request_serializer=voltha__protos_dot_device__pb2.ImageDownload.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class CoreServiceServicer(object):
    """The CoreService is a gRPC service implemented by the Voltha RW-Core for the
    sole purpose of serving requests/updates from the Voltha adapters. 
    """

    def GetHealthStatus(self, request, context):
        """	 in coreProxy interface
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterAdapter(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeviceUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PortCreated(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PortsStateUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAllPorts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDevicePort(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDevicePorts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeviceStateUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DevicePMConfigUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChildDeviceDetected(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChildDevicesLost(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChildDevicesDetected(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDevice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetChildDevice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetChildDevices(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendPacketIn(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeviceReasonUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PortStateUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReconcileChildDevices(self, request, context):
        """Additional API found in the Core - unused?
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetChildDeviceWithProxyAddress(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPorts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChildrenStateUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateImageDownload(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CoreServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetHealthStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHealthStatus,
                    request_deserializer=voltha__protos_dot_common__pb2.Connection.FromString,
                    response_serializer=voltha__protos_dot_health__pb2.HealthStatus.SerializeToString,
            ),
            'RegisterAdapter': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterAdapter,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.AdapterRegistration.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeviceUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.DeviceUpdate,
                    request_deserializer=voltha__protos_dot_device__pb2.Device.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'PortCreated': grpc.unary_unary_rpc_method_handler(
                    servicer.PortCreated,
                    request_deserializer=voltha__protos_dot_device__pb2.Port.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'PortsStateUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.PortsStateUpdate,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.PortStateFilter.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteAllPorts': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAllPorts,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetDevicePort': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDevicePort,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.PortFilter.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.Port.SerializeToString,
            ),
            'ListDevicePorts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDevicePorts,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.Ports.SerializeToString,
            ),
            'DeviceStateUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.DeviceStateUpdate,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.DeviceStateFilter.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DevicePMConfigUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.DevicePMConfigUpdate,
                    request_deserializer=voltha__protos_dot_device__pb2.PmConfigs.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ChildDeviceDetected': grpc.unary_unary_rpc_method_handler(
                    servicer.ChildDeviceDetected,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.DeviceDiscovery.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.Device.SerializeToString,
            ),
            'ChildDevicesLost': grpc.unary_unary_rpc_method_handler(
                    servicer.ChildDevicesLost,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ChildDevicesDetected': grpc.unary_unary_rpc_method_handler(
                    servicer.ChildDevicesDetected,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDevice,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.Device.SerializeToString,
            ),
            'GetChildDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.GetChildDevice,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.ChildDeviceFilter.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.Device.SerializeToString,
            ),
            'GetChildDevices': grpc.unary_unary_rpc_method_handler(
                    servicer.GetChildDevices,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.Devices.SerializeToString,
            ),
            'SendPacketIn': grpc.unary_unary_rpc_method_handler(
                    servicer.SendPacketIn,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.PacketIn.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeviceReasonUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.DeviceReasonUpdate,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.DeviceReason.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'PortStateUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.PortStateUpdate,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.PortState.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ReconcileChildDevices': grpc.unary_unary_rpc_method_handler(
                    servicer.ReconcileChildDevices,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetChildDeviceWithProxyAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.GetChildDeviceWithProxyAddress,
                    request_deserializer=voltha__protos_dot_device__pb2.Device.ProxyAddress.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.Device.SerializeToString,
            ),
            'GetPorts': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPorts,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.PortFilter.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.Ports.SerializeToString,
            ),
            'ChildrenStateUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.ChildrenStateUpdate,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.DeviceStateFilter.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateImageDownload': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateImageDownload,
                    request_deserializer=voltha__protos_dot_device__pb2.ImageDownload.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'core_service.CoreService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CoreService(object):
    """The CoreService is a gRPC service implemented by the Voltha RW-Core for the
    sole purpose of serving requests/updates from the Voltha adapters. 
    """

    @staticmethod
    def GetHealthStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/GetHealthStatus',
            voltha__protos_dot_common__pb2.Connection.SerializeToString,
            voltha__protos_dot_health__pb2.HealthStatus.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterAdapter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/RegisterAdapter',
            voltha__protos_dot_core__adapter__pb2.AdapterRegistration.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeviceUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/DeviceUpdate',
            voltha__protos_dot_device__pb2.Device.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PortCreated(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/PortCreated',
            voltha__protos_dot_device__pb2.Port.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PortsStateUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/PortsStateUpdate',
            voltha__protos_dot_core__adapter__pb2.PortStateFilter.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAllPorts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/DeleteAllPorts',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDevicePort(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/GetDevicePort',
            voltha__protos_dot_core__adapter__pb2.PortFilter.SerializeToString,
            voltha__protos_dot_device__pb2.Port.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDevicePorts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/ListDevicePorts',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_device__pb2.Ports.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeviceStateUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/DeviceStateUpdate',
            voltha__protos_dot_core__adapter__pb2.DeviceStateFilter.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DevicePMConfigUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/DevicePMConfigUpdate',
            voltha__protos_dot_device__pb2.PmConfigs.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChildDeviceDetected(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/ChildDeviceDetected',
            voltha__protos_dot_core__adapter__pb2.DeviceDiscovery.SerializeToString,
            voltha__protos_dot_device__pb2.Device.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChildDevicesLost(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/ChildDevicesLost',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChildDevicesDetected(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/ChildDevicesDetected',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/GetDevice',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_device__pb2.Device.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetChildDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/GetChildDevice',
            voltha__protos_dot_core__adapter__pb2.ChildDeviceFilter.SerializeToString,
            voltha__protos_dot_device__pb2.Device.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetChildDevices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/GetChildDevices',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_device__pb2.Devices.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendPacketIn(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/SendPacketIn',
            voltha__protos_dot_core__adapter__pb2.PacketIn.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeviceReasonUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/DeviceReasonUpdate',
            voltha__protos_dot_core__adapter__pb2.DeviceReason.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PortStateUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/PortStateUpdate',
            voltha__protos_dot_core__adapter__pb2.PortState.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReconcileChildDevices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/ReconcileChildDevices',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetChildDeviceWithProxyAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/GetChildDeviceWithProxyAddress',
            voltha__protos_dot_device__pb2.Device.ProxyAddress.SerializeToString,
            voltha__protos_dot_device__pb2.Device.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPorts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/GetPorts',
            voltha__protos_dot_core__adapter__pb2.PortFilter.SerializeToString,
            voltha__protos_dot_device__pb2.Ports.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChildrenStateUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/ChildrenStateUpdate',
            voltha__protos_dot_core__adapter__pb2.DeviceStateFilter.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateImageDownload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core_service.CoreService/UpdateImageDownload',
            voltha__protos_dot_device__pb2.ImageDownload.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
